@@ -30,8 +30,9 @@ except ImportError:
     openstackdocstheme = None
 
 # openstackdocstheme options
-repository_name = 'openstack/virtualbmc'
-use_storyboard = True
+openstackdocs_repo_name = 'openstack/virtualbmc'
+openstackdocs_pdf_link = True
+openstackdocs_use_storyboard = True
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
@@ -54,7 +55,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
